@@ -4,9 +4,7 @@ use warnings; use strict;
 use Mouse;
 use Mouse::Util::TypeConstraints;
 
-use Try::Tiny;
-
-use Elive::DAO '0.06';
+use Elive::DAO '1.34';
 extends 'Elive::DAO';
 
 use Carp;
@@ -21,19 +19,19 @@ Version 0.01_4
 
 =cut
 
-our $VERSION = '0.01_4';
+our $VERSION = '0.01_5';
 
 =head1 DESCRIPTION
 
 Elluminate Live! (c) is software for virtual online classrooms. It is
-suitable for meetings, demonstrations web conferences, seminars and
-general training and support.
+suitable for meetings, demonstrations web conferences, seminars, general
+training and support.
 
 Elive-StandardV3 is a set of Perl bindings and entity definitions for the
-Elluminate Standard Bridge V3 SOAP services ('standardv3' adapter).
+Elluminate Standard Bridge V3 SOAP services (C<standardv3> adapter).
 
 This is an alternative to the Command Toolkit, as supported by the
-Elive::Entity classess ('default' adapter).
+L<Elive::Entity> classess (bindings to the C<default> adapter).
 
 =cut
 
@@ -141,8 +139,7 @@ sub connect {
     die "usage: ${class}->connect(url, [login_name], [pass])"
 	unless ($class && $url);
 
-    try {require Elive::StandardV3::Connection}
-    catch {die $_};
+    require Elive::StandardV3::Connection;
 
     my $connection = Elive::StandardV3::Connection->connect(
 	$url,
@@ -272,12 +269,12 @@ sub _parse_filter {
 	my ($field, $op, $val) = m{^ \s* (\w+) \s* ([\!=<>]+) \s* (.*?) \s* $}x;
 
 	unless (defined($val) && length($val) && $op eq '=') {
-	    carp "selection expresion '$_' not in format <field> = <val>";
+	    carp "selection expression '$_' not in format <field> = <val>";
 	    next;
 	}
 
 	$selection{$field} = $val;
-    } ;
+    }
 
     return \%selection;
 }
@@ -307,10 +304,7 @@ sub delete {
 
     my $som = $self->connection->call($command, @params);
 
-    my $results = $self->_get_results(
-	$som,
-	$self->connection,
-	);
+    my $results = $self->_get_results( $som, $self->connection );
 
     my $success = @$results && $results->[0];
 
@@ -376,7 +370,7 @@ L<http://search.cpan.org/dist/Elive-StandardV3/>
 
 =head1 SEE ALSO
 
-I<Standard Integration API Guide for ELM.pdf> - this contains essential
+I<Standard Integration API Guide V3 for ELM.pdf> - this contains essential
 background information and a full description of the available commands.
 
 =head1 ACKNOWLEDGEMENTS
