@@ -186,7 +186,7 @@ Maximum number of simultaneous video cameras to be configured in the Elluminate
 
 For single server configurations, this value must be between 1 and C<maxAvailableCameras> (as returned from the L<Elive::StandardV3::ServerConfiguration> C<get()> command).
 
-For multiple server configurations, this must be between 1 and versionMaxFilmersLimit for the version you are using (as returned from the L<Elive::StandardV3::ServerVersions> C<get()> command).
+For multiple server configurations, this must be between 1 and versionMaxFilmersLimit for the version you are using (as returned from the L<Elive::StandardV3::ServerVersion> C<get()> command).
 
 If you don't specify a value, the default is taken from the C<Maximum Simultaneous Cameras> setting in the Default Session Preferences.
 
@@ -202,7 +202,7 @@ Maximum number of simultaneous talkers to be configured in the Elluminate Live!
 
 For single server configurations, this value must be between 1 and C<maxAvailableTalkers> property (as returned from the L<Elive::StandardV3::ServerConfiguration> C<get()> command).
 
-For multiple server configurations, this must be between 1 and C<versionMaxTalkersLimit> for the version you are using (as returned from the C<Elive::StandardV3::ServerVersions> C<get()> command).
+For multiple server configurations, this must be between 1 and C<versionMaxTalkersLimit> for the version you are using (as returned from the L<Elive::StandardV3::ServerVersion> C<get()> command).
 
 If you don't specify a value, the default is taken from the C<Maximum Simultaneous Talkers> setting in the Default Session Preferences.
 
@@ -371,7 +371,17 @@ has 'versionId' => (is => 'rw', isa => 'Int',
 sub _readback_check {
     my ($class, $_updates_ref, $rows, @args) = @_;
     my %updates = %$_updates_ref;
+
     #
+    # sessionName is a bit SHOUTY on SAS. Do case insenstive comparision
+    #
+    if (my $session_name = delete $updates{sessionName}) {
+        for (map {$_->{sessionName}} @$rows) {
+            die " Update consistancy check failed on sessionName, sent:$session_name, read-back:$_"
+                if $_ and uc $session_name ne uc;
+        }
+    }
+
     # cop out of checking start and end times for recurring
     # sessions
     #
@@ -438,7 +448,7 @@ A series of sessions can be created using the C<recurrenceCount> and C<recurrenc
     #
     $session->update({maxCameras => 5, hideParticipantNames => 0});
 
-Updates a previous created session.
+Updates an existing session.
 
 =cut
 
@@ -539,7 +549,7 @@ sub telephony {
 
     $session->set_presentation($presentation);
 
-Aossociates the presenetation with a session.
+Aossociates a seession with presentation content.
 
 =cut
 
@@ -562,7 +572,7 @@ sub set_presentation {
 
     my $som = $connection->call($command => %$params);
 
-    my $results = $class->_get_results(	$som, $connection );
+    my $results = $class->_get_results( $som, $connection );
 
     my $success = @$results && $results->[0];
 
@@ -573,7 +583,7 @@ sub set_presentation {
 
     $session->set_multimedia([$multimedia_1, $multimedia_2]);
 
-Associates a session with Multimedia content.
+Associates a session with multimedia content.
 
 =cut
 
@@ -605,7 +615,7 @@ sub set_multimedia {
     my $command = $opt{command} || 'SetSessionMultimedia';
     my $som = $connection->call($command => %$params);
 
-    my $results = $class->_get_results(	$som, $connection );
+    my $results = $class->_get_results( $som, $connection );
 
     my $success = @$results && $results->[0];
 
@@ -655,7 +665,7 @@ sub list_presentation {
     my $presentation_list = $session->list_presentation;
 
     foreach my $presentation_item (@$presentation_list) {
-        $session->rmemove_presentation( $presentation_item );
+        $session->remove_presentation( $presentation_item );
     }
 
 Disassociate the given presentation item from the session
@@ -695,7 +705,7 @@ sub remove_presentation {
     my $multimedia_list = $session->list_multimedia;
 
     foreach my $multimedia_item (@$multimedia_list) {
-        $session->rmemove_multimedia( $multimedia_item );
+        $session->remove_multimedia( $multimedia_item );
     }
 
 Disassociate the given multimedia item from the session
@@ -797,7 +807,7 @@ sub session_url {
 
 =head2 set_api_callback_url
 
-    my $session_url = $session->session_url($url);
+    my $session_url = $session->set_api_callback_url($url);
 
 This method calls the C< SetApiCallbackUrl> command, which is used to specify a
 callback URL that will be notified every time a room closes.
